ORB_RECALL_CONFIG = {
    "per_levels": [ 40, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 2 ],
    "per_stars": [ 120, 200, 320, 560, 800 ]
}

DRAGON_MIN_LEVEL = 1
DRAGON_MAX_LEVEL = 70
DRAGON_MIN_STARS = 0
DRAGON_MAX_STARS = 5

__all__ = [
    ORB_RECALL_CONFIG,
    DRAGON_MIN_LEVEL,
    DRAGON_MAX_LEVEL
]